# Superpower GUI
> This application provides a graphical wrapper to access functions in the superpower R pacakge.


## Install

`git clone https://github.rcac.purdue.edu/brewer36/superpower_gui.git`

`cd superpower_gui`

`pip install superpower_gui`

## How to use

This application runs in a single cell of a Jupyter Notebook, or an Javascript enabled IPython environment.

```
controller = Controller()
```

```
controller
```
